==> sagua_0.2.3-1.tar.gz: sagua-0.2.3/include/urldlg.h <==
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
#ifndef GUARD_urldlg_h
#define GUARD_urldlg_h
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file urldlg.h
/// @brief Class for 'URL add dialog' header file.

#include <string>

#include <gtkmm/dialog.h>
#include <gtkmm/label.h>
#include <gtkmm/entry.h>

/// @brief Class for 'URL add dialog'.
class UrlDlg : public Gtk::Dialog
{
public:
    UrlDlg();
    virtual ~UrlDlg();

    /// @brief Return selected url, UTF-8 encoding text.
    const std::string& SelectedUrl() const
    {
        return selectedUrl_;
    }

private:
    Gtk::Label infoLabel_;
    Gtk::Entry urlEntry_;

    std::string selectedUrl_;

    void OnBtnOk();
    void OnBtnCancel();
};

#endif

==> sagua_0.2.4-1.tar.gz: sagua-0.2.4/include/urldlg.h <==
#ifndef GUARD_urldlg_h
#define GUARD_urldlg_h
/* -*- Mode: C++; tab-width: 4; indent-tabs-mod: nil; c-basic-offset: 4 -*- */
// Sagua is music player.
// Copyright (C) 2004 HG, Rhee <ez8tank@krpost.net>
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

/// @file urldlg.h
/// @brief Class for 'URL add dialog' header file.

//#include <string>

#include <gtkmm/dialog.h>
#include <gtkmm/label.h>
#include <gtkmm/entry.h>

/// @brief Class for 'URL add dialog'.
class UrlDlg
{
public:
    UrlDlg(Gtk::Window& parent);
    ~UrlDlg() {}

    int Run()
    {
        return urlDlg_.run();
    }

    /// @brief Return selected url, UTF-8 encoded text.
    Glib::ustring SelectedUrl() const
    {
        return urlEntry_.get_text();
    }

private:
    Gtk::Dialog urlDlg_;
    Gtk::Label infoLabel_;
    Gtk::Entry urlEntry_;

    void OnBtnOk();
    void OnBtnCancel();

    void LabelInit();

    void DialogInit()
    {
        urlDlg_.set_resizable(false);
    }

    void DialogPacking();
    void DialogAddButtons();
};

#endif
